@@ -209,7 +209,7 @@ pmg <- function(formula, data, subset, na.action,
         tcoef0[ , i] <- tfit$coefficients
         tres[[i]]    <- tfit$residuals
       }
-      tcoef     <- tcoef0[1:k, ]
+      tcoef     <- tcoef0[1:k, ] # TODO: this line seems superfluous as tcoef is overwritten a few lines below again
       tcoef.bar <- tcoef0[-(1:k), ]
 
       coef.names.bar <- c("y.bar", paste(coef.names[-1L], ".bar", sep=""))
