@@ -121,7 +121,7 @@ fancy.row.names <- function(index, sep = "-") {
 #' @param replace.non.finite logical, indicating whether values for
 #'     which `is.finite()` yields `TRUE` are to be replaced by `NA`
 #'     values, except for character variables (defaults to `FALSE`),
-#' @param drop.NA.series logical, indicating whether all-NA columns
+#' @param drop.NA.series logical, indicating whether all-`NA` columns
 #'     are to be removed from the pdata.frame (defaults to `FALSE`),
 #' @param drop.const.series logical, indicating whether constant
 #'     columns are to be removed from the pdata.frame (defaults to
@@ -174,7 +174,7 @@ fancy.row.names <- function(index, sep = "-") {
 #' 
 #' 
 pdata.frame <- function(x, index = NULL, drop.index = FALSE, row.names = TRUE,
-                        stringsAsFactors = default.stringsAsFactors(),
+                        stringsAsFactors = FALSE,
                         replace.non.finite = FALSE,
                         drop.NA.series = FALSE, drop.const.series = FALSE,
                         drop.unused.levels = FALSE) {
@@ -654,7 +654,7 @@ subset_pseries <- function(x, ...) {
         res <- structure(mydata,
                          names = x.rownames,
                          index = index,
-                         class = base::union("pseries", class(mydata)))
+                         class = unique(c("pseries", class(mydata))))
       }
     } else {
           # subsetting returned a data.frame -> add attributes to make it a pdata.frame again
@@ -678,7 +678,7 @@ subset_pseries <- function(x, ...) {
     # use this order for attributes to preserve original order of attributes for a pseries
     result <- structure(result,
                         names = row.names(x),
-                        class = base::union("pseries", class(result)),
+                        class = unique(c("pseries", class(result))),
                         index = index 
                         )
   }
@@ -828,7 +828,7 @@ as.data.frame.pdata.frame <- function(x, row.names = NULL, optional = FALSE, kee
                                                  # in columns because the call to data.frame later deletes
                                                  # the names attribute of columns (definition of data frame)
                     attr(z, "index") <- index
-                    class(z) <- base::union("pseries", class(z))
+                    class(z) <- unique(c("pseries", class(z)))
                     return(z)
                   })
     }
@@ -958,7 +958,7 @@ is.pseries <- function(object) {
 #'     observations (individual, time) actually used for model
 #'     estimation are taken into account.  When called on a
 #'     `(p)data.frame`, the rows in the `(p)data.frame` are
-#'     considered, disregarding any NA values in the dependent or
+#'     considered, disregarding any `NA`values in the dependent or
 #'     independent variable(s) which would be dropped during model
 #'     estimation.
 #' @export
@@ -1043,9 +1043,23 @@ pdim.pseries <- function(x,...) {
 
 #' @rdname pdim
 #' @export
-pdim.panelmodel <- function(x, ...) {
-  x <- model.frame(x)
-  pdim(x)
+pdim.pggls <- function(x, ...) {
+  ## pggls is also class panelmodel, but take advantage of the pdim attribute in it
+  attr(x, "pdim")
+}
+
+#' @rdname pdim
+#' @export
+pdim.pcce <- function(x, ...) {
+  ## pcce is also class panelmodel, but take advantage of the pdim attribute in it
+  attr(x, "pdim")
+}
+
+#' @rdname pdim
+#' @export
+pdim.pmg <- function(x, ...) {
+  ## pmg is also class panelmodel, but take advantage of the pdim attribute in it
+  attr(x, "pdim")
 }
 
 #' @rdname pdim
@@ -1055,6 +1069,13 @@ pdim.pgmm <- function(x, ...) {
   attr(x, "pdim")
 }
 
+#' @rdname pdim
+#' @export
+pdim.panelmodel <- function(x, ...) {
+  x <- model.frame(x)
+  pdim(x)
+}
+
 #' @rdname pdim
 #' @export
 print.pdim <- function(x, ...) {
