@@ -53,8 +53,6 @@
 #'     specifying the dimension (`"twoways"` is not possible),
 #' @param idbyrow if `TRUE` in the `as.matrix` method, the lines of
 #'     the matrix are the individuals,
-#' @param rm.null if `TRUE`, for the `Within.matrix` method, remove
-#'     the empty columns,
 #' @param plot,scale,transparency,col,lwd plot arguments,
 #' @param \dots further arguments, e. g., `na.rm = TRUE` for
 #'     transformation functions like `beetween`, see **Details**
@@ -221,7 +219,9 @@ plot.pseries <- function(x, plot = c("lattice", "superposed"),
 #' @rdname pseries
 #' @export
 summary.pseries <- function(object, ...) {
-    if(!inherits(object, c("factor", "logical", "character"))) {
+    object.orig <- object
+    special_treatment_vars <- c("factor", "logical", "character")
+    if(!inherits(object, special_treatment_vars)) {
         index <- unclass(attr(object, "index")) # unclass for speed
         id   <- index[[1L]]
         time <- index[[2L]]
@@ -234,11 +234,14 @@ summary.pseries <- function(object, ...) {
         res <- structure(c(total        = sum( (na.omit(object) - mean(object, na.rm = TRUE)) ^ 2),
                            between_id   = sum( (na.omit(Bid)    - mean(Bid,    na.rm = TRUE)) ^ 2),
                            between_time = sum( (na.omit(Btime)  - mean(Btime,  na.rm = TRUE)) ^ 2)), 
-                          class = c("summary.pseries", "numeric"))
+                          class = c("summary.pseries"),
+                          class.pseries = class(object.orig))
+        attr(res, "SummaryDefault") <- summary(remove_pseries_features(object))
     } else {
-        class(object) <- setdiff(class(object), c("pseries"))
+        object <- remove_pseries_features(object)
         res <- summary(object, ...)
-        class(res) <- c("summary.pseries", class(object), class(res))
+        attr(res, "class.pseries") <- class(object.orig)
+        class(res) <- c("summary.pseries")
     }
     return(res)
 }
@@ -246,10 +249,14 @@ summary.pseries <- function(object, ...) {
 #' @rdname pseries
 #' @export
 plot.summary.pseries <- function(x, ...){
-    x <- as.numeric(x)
-    share <- x[-1L]/x[1L] # vec with length == 2
-    names(share) <- c("id", "time")
-    barplot(share, ...)
+    special_treatment_vars <- c("factor", "logical", "character")
+    class.basic <- setdiff(attr(x, "class.pseries"), "pseries")
+    if(!class.basic %in% special_treatment_vars) {
+      x <- as.numeric(x) # get tss, id/time b by coercing summary.pseries to 'numeric'
+      share <- x[-1L]/x[1L] # vec with length == 2
+      names(share) <- c("id", "time")
+      barplot(share, ...)
+    } else NULL
 }
 
 #' @rdname pseries
@@ -258,14 +265,21 @@ print.summary.pseries <- function(x, ...){
     x.orig <- x
     digits <- getOption("digits")
     special_treatment_vars <- c("factor", "logical", "character")
-    if(!inherits(x, special_treatment_vars)) {
-        x <- as.numeric(x)
+    class.basic <- setdiff(attr(x, "class.pseries"), "pseries")
+    if(!class.basic %in% special_treatment_vars) {
+        x <- as.numeric(x) # get tss, id/time b by coercing summary.pseries to 'numeric'
         share <- x[-1L]/x[1L] # vec with length == 2
         names(share) <- c("id", "time")
         cat(paste("total sum of squares:", signif(x[1L], digits = digits),"\n"))
         print.default(share, ...)
+        cat("\n")
+        print(attr(x.orig, "SummaryDefault"), ...)
     } else {
-        class(x) <- setdiff(class(x), c("summary.pseries", special_treatment_vars))
+      # use base R's facilities
+        attr(x, "class.pseries") <- NULL
+        # factor is special once again:
+        is.fac <- if(class.basic == "factor") TRUE else FALSE
+        attr(x, "class") <- if(is.fac) NULL else "summaryDefault"
         print(x, ...)
     }
     invisible(x.orig)
@@ -590,20 +604,15 @@ Within.pseries <- function(x, effect = c("individual", "time", "group", "twoways
 
 #' @rdname pseries
 #' @export
-Within.matrix <- function(x, effect, rm.null = TRUE, ...) {
+Within.matrix <- function(x, effect, ...) {
 # print("Within.matrix(.baseR)")
 # browser()
   
     if(is.null(xindex <- unclass(attr(x, "index")))) { # unclass for speed
       # non-index case
         result <- Within.default(x, effect, ...)
-        othervar <- colSums(abs(x)) > sqrt(.Machine$double.eps)
-        if(rm.null) {
-            result <- result[ , othervar, drop = FALSE]
-            attr(result, "constant") <- character(0)
-        }
-        else attr(result, "constant") <- colnames(x)[! othervar]
-        return(result)
+        # NB: effect is assumed to be a factor; contrary to the other Within.* 
+        #     methods, Within.default does not handle twoways effects
     }
     else {
       # index case
@@ -618,7 +627,7 @@ Within.matrix <- function(x, effect, rm.null = TRUE, ...) {
                 time <- xindex[[2L]]
                 Dmu <- model.matrix(~ time - 1)
                 attr(Dmu, "index") <- attr(x, "index") # need orig. index here
-                W1   <- Within(x,   "individual", rm.null = FALSE, ...)
+                W1   <- Within(x,   "individual", ...)
                 WDmu <- Within(Dmu, "individual", ...)
                 W2 <- lm.fit(WDmu, x)$fitted.values
                 result <- W1 - W2
@@ -873,7 +882,7 @@ alagt <- function(x, ak) {
     NApos <- is.na(index_lag_ak_all) # save NA positions for later
     substitute_blockwise <- index_lag_ak_all
     
-    block_lengths <- vapply(index_lag_ak_all_list, length, FUN.VALUE = 0.0, USE.NAMES = FALSE)
+    block_lengths <- lengths(index_lag_ak_all_list, use.names = FALSE)
     
     # not needed but leave here for illustration:
     #    startpos_block <- cumsum(block_lengths) - block_lengths + 1
@@ -992,7 +1001,7 @@ diffr.pseries <- function(x, lag = 1L, ...) {
     return(res)
 }
 
-## pdiff is (only) used in model.matrix.pFormula to calculate the
+## pdiff is (only) used in model.matrix to calculate the
 ## model.matrix for FD models, works for effect = "individual" only,
 ## see model.matrix on how to call pdiff. Result is in order (id,
 ## time) for both effects
